FunctionStatus

Struct FunctionStatus 

pub struct FunctionStatus {
Show 18 fields pub ack_resource_metadata: Option<FunctionStatusAckResourceMetadata>, pub code_sha256: Option<String>, pub code_size: Option<i64>, pub conditions: Option<Vec<Condition>>, pub image_config_response: Option<FunctionStatusImageConfigResponse>, pub last_modified: Option<String>, pub last_update_status: Option<String>, pub last_update_status_reason: Option<String>, pub last_update_status_reason_code: Option<String>, pub layer_statuses: Option<Vec<FunctionStatusLayerStatuses>>, pub master_arn: Option<String>, pub revision_id: Option<String>, pub signing_job_arn: Option<String>, pub signing_profile_version_arn: Option<String>, pub state: Option<String>, pub state_reason: Option<String>, pub state_reason_code: Option<String>, pub version: Option<String>,
}
FunctionStatus defines the observed state of Function

Fields

ack_resource_metadata: Option<FunctionStatusAckResourceMetadata>

All CRs managed by ACK have a common Status.ACKResourceMetadata member that is used to contain resource sync state, account ownership, constructed ARN for the resource

code_sha256: Option<String>

The SHA256 hash of the function’s deployment package.

code_size: Option<i64>

The size of the function’s deployment package, in bytes.

conditions: Option<Vec<Condition>>

All CRs managed by ACK have a common Status.Conditions member that contains a collection of ackv1alpha1.Condition objects that describe the various terminal states of the CR and its backend AWS service API resource

image_config_response: Option<FunctionStatusImageConfigResponse>

The function’s image configuration values.

last_modified: Option<String>

The date and time that the function was last updated, in ISO-8601 format (https://www.w3.org/TR/NOTE-datetime) (YYYY-MM-DDThh:mm:ss.sTZD).

last_update_status: Option<String>

The status of the last update that was performed on the function. This is first set to Successful after function creation completes.

last_update_status_reason: Option<String>

The reason for the last update that was performed on the function.

last_update_status_reason_code: Option<String>

The reason code for the last update that was performed on the function.

layer_statuses: Option<Vec<FunctionStatusLayerStatuses>>master_arn: Option<String>

For Lambda@Edge functions, the ARN of the main function.

Regex Pattern: ^arn:(aws[a-zA-Z-]*)?:lambda:[a-z]{2}((-gov)|(-iso([a-z]?)))?-[a-z]+-\d{1}:\d{12}:function:[a-zA-Z0-9-_]+(:(\$LATEST|[a-zA-Z0-9-_]+))?$

revision_id: Option<String>

The latest updated revision of the function or alias.

signing_job_arn: Option<String>

The ARN of the signing job.

Regex Pattern: ^arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\-])+:([a-z]{2}(-gov)?-[a-z]+-\d{1})?:(\d{12})?:(.*)$

signing_profile_version_arn: Option<String>

The ARN of the signing profile version.

Regex Pattern: ^arn:(aws[a-zA-Z0-9-]*):([a-zA-Z0-9\-])+:([a-z]{2}(-gov)?-[a-z]+-\d{1})?:(\d{12})?:(.*)$

state: Option<String>

The current state of the function. When the state is Inactive, you can reactivate the function by invoking it.

state_reason: Option<String>

The reason for the function’s current state.

state_reason_code: Option<String>

The reason code for the function’s current state. When the code is Creating, you can’t invoke or modify the function.

version: Option<String>

The version of the Lambda function.

Regex Pattern: ^(\$LATEST|[0-9]+)$